# Embedded file name: /media/build/vti-dorie/build/tmp/work/all-oe-linux/vti-addon/vti-addon-2.26-r20200910.15.0.02/Converter/ExtendedServiceInfo.py
from Components.config import config
from Components.Converter.Converter import Converter
from Components.Element import cached
from enigma import eServiceCenter, eServiceReference, iServiceInformation, iPlayableServicePtr
from xml.etree.cElementTree import parse

class ExtendedServiceInfoWeFr(Converter, object):
	SERVICENAME = 0
	SERVICENUMBER = 1
	NUMBERNAME = 2
	ORBITALPOSITION = 3
	SATNAME = 4
	PROVIDER = 5
	CONTAINEDINBOUQUET = 6
	CONTAINEDINBOUQUETVERT= 7
	ALL = 8

	def __init__(self, type):
		Converter.__init__(self, type)
		self.satNames = {}
		self.readSatXml()
		self.getLists()
		type = type.upper()
		if type == 'SERVICENAME':
			self.type = self.SERVICENAME
		elif type == 'SERVICENUMBER':
			self.type = self.SERVICENUMBER
		elif type == 'NUMBERNAME':
			self.type = self.NUMBERNAME
		elif type == 'ORBITALPOSITION':
			self.type = self.ORBITALPOSITION
		elif type == 'SATNAME':
			self.type = self.SATNAME
		elif type == 'PROVIDER':
			self.type = self.PROVIDER
		elif type == 'CONTAINEDINBOUQUET':
			self.type = self.CONTAINEDINBOUQUET
		elif type == 'CONTAINEDINBOUQUETVERT':
			self.type = self.CONTAINEDINBOUQUETVERT
		else:
			self.type = self.ALL

	@cached
	def getText(self):
		service = self.source.service
		try:
			info = service and service.info()
			if not info:
				return ''
			globalService = True
		except:
			globalService = False

		text = ''
		if globalService:

			if self.type == self.SERVICENAME:
				name = info.getName().replace('\xc2\x86', '').replace('\xc2\x87', '')
				text = name
			elif self.type == self.SERVICENUMBER:
				number = self.getServiceNumber(info.getInfoString(iServiceInformation.sServiceref))
				text = number
			elif self.type == self.NUMBERNAME:
				name = info.getName().replace('\xc2\x86', '').replace('\xc2\x87', '')
				number = self.getServiceNumber(info.getInfoString(iServiceInformation.sServiceref))
				text = number + "   " + name
			elif self.type == self.ORBITALPOSITION:
				orbital = self.getOrbitalPosition(info)
				text = orbital
			elif self.type == self.SATNAME:
				orbital = self.getOrbitalPosition(info)
				satName = self.satNames.get(orbital, orbital)
				text = satName
			elif self.type == self.PROVIDER:
				text = info.getInfoString(iServiceInformation.sProvider)
			elif self.type == self.CONTAINEDINBOUQUET or self.type == self.CONTAINEDINBOUQUETVERT:
				#text = "test"
				#return
				ref = info.getInfoString(iServiceInformation.sServiceref)
				if ref.startswith('1:0:2') or ref.startswith('1:0:A'):
					list = self.radio_list
				else:
					list = self.tv_list
				text = ""
				for x in list:
					if ref == x[0]:
						if text != "":
							text += ", "
						text += str(x[3])
				if text == "":
					text = "--"
				if self.type == self.CONTAINEDINBOUQUETVERT:
					text = text.replace(", ", "\n")
			else:
				name = info.getName().replace('\xc2\x86', '').replace('\xc2\x87', '')
				number = self.getServiceNumber(info.getInfoString(iServiceInformation.sServiceref))
				orbital = self.getOrbitalPosition(info)
				satName = self.satNames.get(orbital, orbital)
				if number == '':
					text = name
				else:
					text = '%s. %s' % (number, name)
				if orbital != '':
					text = '%s (%s)' % (text, orbital)
					
		else:
			if self.type == self.CONTAINEDINBOUQUET or self.type == self.CONTAINEDINBOUQUETVERT:
				ref = self.source.service.toString()
				if ref.startswith('1:0:2') or ref.startswith('1:0:A'):
					list = self.getListFromRef(eServiceReference('1:7:2:0:0:0:0:0:0:0:(type == 2 || type == 10) FROM BOUQUET "bouquets.radio" ORDER BY bouquet'))
				else:
					list = self.getListFromRef(eServiceReference('1:7:1:0:0:0:0:0:0:0:(type == 1) || (type == 17) || (type == 195) || (type == 25) FROM BOUQUET "bouquets.tv" ORDER BY bouquet'))
				text = ""
				for x in list:
					if ref == x[0]:
						if text != "":
							text += ", "
						text += str(x[3])
				if text == "":
					text = "--"
				if self.type == self.CONTAINEDINBOUQUETVERT:
					text = text.replace(", ", "\n")

		return text

	text = property(getText)

	def changed(self, what):
		Converter.changed(self, what)

	def getListFromRef(self, ref):
		list = []
		serviceHandler = eServiceCenter.getInstance()
		services = serviceHandler.list(ref)
		bouquets = services and services.getContent('SN', True)
		numB = 0
		for bouquet in bouquets:
			numB +=1
			services = serviceHandler.list(eServiceReference(bouquet[0]))
			channels = services and services.getContent('SN', True)
			for channel in channels:
				if not channel[0].startswith('1:64:'):
					list.append((channel[0], channel[1].replace('\xc2\x86', '').replace('\xc2\x87', ''), bouquet[0], numB))

		return list

	def getLists(self):
		self.tv_list = self.getListFromRef(eServiceReference('1:7:1:0:0:0:0:0:0:0:(type == 1) || (type == 17) || (type == 195) || (type == 25) FROM BOUQUET "bouquets.tv" ORDER BY bouquet'))
		self.radio_list = self.getListFromRef(eServiceReference('1:7:2:0:0:0:0:0:0:0:(type == 2 || type == 10) FROM BOUQUET "bouquets.radio" ORDER BY bouquet'))
		#print "xxx97 tvlist ", self.tv_list

	def readSatXml(self):
		satXml = parse('/etc/tuxbox/satellites.xml').getroot()
		if satXml is not None:
			for sat in satXml.findall('sat'):
				name = sat.get('name') or None
				position = sat.get('position') or None
				if name is not None and position is not None:
					position = '%s.%s' % (position[:-1], position[-1:])
					if position.startswith('-'):
						position = '%sW' % position[1:]
					else:
						position = '%sE' % position
					if position.startswith('.'):
						position = '0%s' % position
					self.satNames[position] = name

		return

	def getServiceNumber(self, ref):
		list = []
		isRadioService = False
		if ref.startswith('1:0:2') or ref.startswith('1:0:A'):
			list = self.radio_list
			isRadioService = True
		else:
			list = self.tv_list
		number = ''
		lastpath = isRadioService and config.radio.lastroot.value or config.tv.lastroot.value
		if 'FROM BOUQUET' not in lastpath:
			if 'FROM PROVIDERS' in lastpath:
				number = 'P'
			elif 'FROM SATELLITES' in lastpath:
				number = 'S'
			elif ') ORDER BY name' in lastpath:
				number = 'A'
		rootstr = ''
		for x in lastpath.split(';'):
			if x != '':
				rootstr = x

		cur = eServiceReference(rootstr).getPath()
		if not config.usage.multibouquet.value:
			if isRadioService:
				if '||' in config.radio.lastroot.value:
					cur = 'FROM BOUQUET "userbouquet.favourites.radio" ORDER BY bouquet'
			else:
				if '||' in config.tv.lastroot.value:
					cur = 'FROM BOUQUET "userbouquet.favourites.tv" ORDER BY bouquet'
		
		
		if ref.count(':') >= 11:
			curref = ref.rsplit(':', 2)
		else:
			curref = ref.rsplit(':', 1)
		if number == '':
			if len(list) > 1:
				xlen = len(list)
				for idx in range(0, xlen):
					if curref[0] in list[idx][0] and cur in list[idx][2]:
						number = str(idx + 1)
						break
		elif len(list) > 0:
			xlen = len(list)
			for idx in range(0, xlen):
				if curref[0] in list[idx][0]:
					number = str(idx + 1)
					break

		return number

	def getOrbitalPosition(self, info):
		transponderData = info.getInfoObject(iServiceInformation.sTransponderData)
		orbital = 0
		if transponderData is not None:
			if isinstance(transponderData, float):
				return ''
			if transponderData.has_key('tuner_type'):
				if transponderData['tuner_type'] == 'DVB-S' or transponderData['tuner_type'] == 'DVB-S2':
					orbital = transponderData['orbital_position']
					orbital = int(orbital)
					if orbital > 1800:
						orbital = str(float(3600 - orbital) / 10.0) + 'W'
					else:
						orbital = str(float(orbital) / 10.0) + 'E'
					return orbital
		return ''